Module: VagrantPlugins::Compose
- Defined in:
- lib/vagrant/compose.rb,
lib/vagrant/compose/config.rb,
lib/vagrant/compose/errors.rb,
lib/vagrant/compose/plugin.rb,
lib/vagrant/compose/util/node.rb,
lib/vagrant/compose/util/cluster.rb,
lib/vagrant/compose/util/node_group.rb
Defined Under Namespace
Modules: Errors Classes: Cluster, Config, Node, NodeGroup, Plugin
Class Method Summary collapse
-
.source_root ⇒ Pathname
This returns the path to the source of this plugin.
Class Method Details
.source_root ⇒ Pathname
This returns the path to the source of this plugin.
14 15 16 |
# File 'lib/vagrant/compose.rb', line 14 def self.source_root @source_root ||= Pathname.new(File.("../../", __FILE__)) end |